#!/usr/bin/bash
# Atomicorp, Inc
# Copyrigth 2024
# Summary: Common shell functions

function dist_detection() {
    if [[ $DEBUG -ge 1 ]]; then
        log_event "DEBUG1: $0: dist_detection START"
    fi

    # Global
    SED=sed
    AWK=awk
    if [ -f /etc/release ]; then
        RELEASE=/etc/release
        DIST="solaris"
        PKG=pkg
	SED=gsed
	AWK=gawk
	SIG_DIR="/var/opt/csw/clamav/db/"
	export PATH=/opt/csw/bin:$PATH

    elif [ -f /etc/redhat-release ]; then
        RELEASE=/etc/redhat-release
    elif [ -f /etc/os-release ]; then
        RELEASE=/etc/os-release
    elif [ -f /etc/openvz-release ]; then
        RELEASE=/etc/openvz-release
    elif [ -f /etc/SuSE-release ]; then
        RELEASE=/etc/SuSE-release
    elif [ -f /etc/lsb-release ]; then
        RELEASE=/etc/lsb-release
    elif [ -f /etc/debian_version ]; then
        RELEASE=/etc/debian_version
    elif [[ $OSTYPE == "aix"* ]]; then
        PKG=aix
        DIST="aix"
        SED=/opt/freeware/bin/sed
    fi

    if [[ -z "$DIST" ]]; then
        PKG=rpm
        if egrep -q "(release 5)" $RELEASE ; then
            DIST="el5"
        elif egrep -q "(release 6|release 2012)" $RELEASE ; then
            DIST="el6"
        elif egrep -q "(release 7|release 2014)" $RELEASE ; then
            DIST="el7"
        elif egrep -q "(release 8)" $RELEASE ; then
            DIST="el8"
        elif egrep -q "(release 9)" $RELEASE ; then
            DIST="el9"
        elif egrep -q "Red Hat Enterprise Linux.* 7" $RELEASE ; then
            DIST="el7"
        elif egrep -q "Red Hat Enterprise Linux.* 8" $RELEASE ; then
            DIST="el8"
        elif egrep -q "(Amazon Linux 2)" $RELEASE; then
            DIST="amazon"
        elif egrep -q "(Amazon Linux AMI|Amazon)" $RELEASE ; then
            DIST="el6"
        elif egrep -q "wheezy" $RELEASE ; then
            DIST="debian"
            PKG=deb
        elif egrep -q "jessie" $RELEASE ; then
            DIST="debian"
            PKG=deb
        elif egrep -q "stretch" $RELEASE ; then
            DIST="debian"
            PKG=deb
        elif egrep -q "buster" $RELEASE ; then
            DIST="debian"
            PKG=deb
        elif egrep -q "bookworm" $RELEASE ; then
            DIST="debian"
            PKG=deb
        elif egrep -q "lucid" $RELEASE ; then
            DIST="debian"
            PKG=deb
        elif egrep -q "precise" $RELEASE ; then
            DIST="debian"
            PKG=deb
        elif egrep -q "Raring Ringtail" $RELEASE ; then
            DIST="debian"
            PKG=deb
        elif egrep -q "Trusty Tahr" $RELEASE ; then
            DIST="ubuntu"
            PKG=deb
        elif egrep -q "Xenial" $RELEASE ; then
            DIST="ubuntu"
            PKG=deb
        elif egrep -q "Bionic" $RELEASE ; then
            DIST="ubuntu"
            PKG=deb
        elif egrep -q "Focal" $RELEASE ; then
            DIST="ubuntu"
            PKG=deb
        elif egrep -q "Jammy" $RELEASE ; then
            DIST="ubuntu"
            PKG=deb
        elif egrep -q "Noble" $RELEASE ; then
            DIST="ubuntu"
            PKG=deb
        fi
    fi

    if [[ $DEBUG -ge 1 ]]; then
        log_event "DEBUG1: $0: dist_detection DIST: ($DIST) PKG: ($PKG) END"
    fi
}


# download_rules <URL> <PATH TO SAVE> 
download() {
    if [ $# -lt 2 ]; then
        echo "Usage: download [-k|--insecure] <URL> <destination_path>"
        return 1
    fi

    local insecure=false
    if [ "$1" = "-k" ] || [ "$1" = "--insecure" ]; then
        insecure=true
        shift
    fi

    url=$1
    destination=$2

    if command -v curl >/dev/null; then
        if [ "$insecure" = true ]; then
            curl -o "$destination" -k "$url" || { echo "Error downloading file from $url"; return 1; }
        else
            curl -o "$destination" "$url" || { echo "Error downloading file from $url"; return 1; }
        fi
    elif command -v wget >/dev/null; then
        wget -O "$destination" "$url" || { echo "Error downloading file from $url"; return 1; }
    else
        if [[ $DEBUG -ge 1 ]]; then
            log_event "Neither ${ID}.malware-detection nor malware-detection found."
        fi
        return 
    fi
}



get_hub_ip() {
    HUB_IP=$($AWK -F'[<>]' '/<address>/ {print $3}' /var/ossec/etc/ossec.conf)
}

# Check if clamd is installed
clamd_version() {
	if [[ $DEBUG -ge 1 ]]; then
		log_event "DEBUG1: $0: clamd_version START"
	fi
	# standard
	if  [ -f /usr/sbin/clamd ]; then
		CLAMD_DAEMON=/usr/sbin/clamd
	elif [ -f /opt/freeware/bin/clamd ]; then
		CLAMD_DAEMON=/opt/freeware/bin/clamd
	elif [ -f /opt/freeware/sbin/clamd ]; then
		CLAMD_DAEMON=/opt/freeware/sbin/clamd
	elif [ -f /opt/csw/sbin/clamd ]; then
		CLAMD_DAEMON=/opt/csw/sbin/clamd
	else
		echo "Error: clamd not detected"
		exit 1
	fi
	if [[ $DEBUG -ge 1 ]]; then
		log_event "DEBUG1: $0: clamd_version:: CLAMD_DAEMON is ($CLAMD_DAEMON)"
	fi


}

# get_freshclam_conf <configfile>
get_freshclam_conf() {
    #echo "DEBUG: get_freshclam_conf::configfile $CONFIG_FILE"
    for line in $(cat $CONFIG_FILE ); do
        if [[ ${line} == setting,* ]]; then
            CLAM_SETTING=$(echo $line |$AWK -F, '{ print $2}')
            CLAM_TOKEN=$(echo $line |$AWK -F, '{ print $3}')
            if [[ ${CLAM_SETTING} == freshclam_* ]]; then
                if [[ ${CLAM_SETTING} == "freshclam_feed_type" ]] && [[ ${CLAM_TOKEN} == "atomic" ]]; then
                    FRESHCLAM_FEED_TYPE="atomic"
                elif [[ ${CLAM_SETTING} == "freshclam_feed_type" ]] && [[ ${CLAM_TOKEN} == "official" ]]; then
                    FRESHCLAM_FEED_TYPE="official"
                elif [[ ${CLAM_SETTING} == "freshclam_feed_type" ]] && [[ ${CLAM_TOKEN} == "hub" ]]; then
                    FRESHCLAM_FEED_TYPE="hub"
                fi

                if [[ ${CLAM_SETTING} == "freshclam_linux_sigs" ]] && [[ ${CLAM_TOKEN} == "true" ]]; then
                    FRESHCLAM_LINUX_SIGS="yes"
                fi
                if [[ ${CLAM_SETTING} == "freshclam_windows_sigs" ]] && [[ ${CLAM_TOKEN} == "true" ]]; then
                    FRESHCLAM_WINDOWS_SIGS="yes"
                fi
                if [[ ${CLAM_SETTING} == "freshclam_android_sigs" ]] && [[ ${CLAM_TOKEN} == "true" ]]; then
                    FRESHCLAM_ANDROID_SIGS="yes"
                fi
                if [[ ${CLAM_SETTING} == "freshclam_osx_sigs" ]] && [[ ${CLAM_TOKEN} == "true" ]]; then
                    FRESHCLAM_OSX_SIGS="yes"
                fi
            fi
        fi
    done

    # Identify the feed owner
    if id clamupdate &>/dev/null; then
        CLAMAV_OWNER=clamupdate
        CLAMAV_GROUP=clamupdate
	elif [ $PKG = "aix" ]; then
        CLAMAV_OWNER=clamav
        CLAMAV_GROUP=system
    else
        CLAMAV_OWNER=clamav
        CLAMAV_GROUP=root
    fi

    if [ -f /etc/freshclam.conf ]; then
	    FRESHCLAM_CONF=/etc/freshclam.conf
    elif [ -f /etc/clamav/freshclam.conf ]; then
	    FRESHCLAM_CONF=/etc/clamav/freshclam.conf
    elif [ -f /etc/opt/csw/freshclam.conf ]; then
	    FRESHCLAM_CONF=/etc/opt/csw/freshclam.conf
    elif [ $PKG == "aix" ]; then
	    FRESHCLAM_CONF=/opt/freeware/etc/clamav/freshclam.conf
    else
	    FRESHCLAM_CONF=/etc/freshclam.conf
    fi	

    if grep ^Example $FRESHCLAM_CONF >/dev/null ; then
	    $SED -i "s/^Example/#Example/g" $FRESHCLAM_CONF
    fi

}


function clamd_setup_and_settings() {
    if [[ $DEBUG -ge 1 ]]; then
        log_event "DEBUG1: clamd_setup_and_settings:: START"
    fi



    case $PKG in
        "rpm")
            # Setup for rpm packages
            if [ -f /etc/clamd.d/scan.conf ]; then
                CLAM_CONF="/etc/clamd.d/scan.conf"
                EPEL=1
                SCAN_D=true
        		if  [ -f /var/ossec/etc/shared/clamd-scan.conf.template ]; then
        			cp /var/ossec/etc/shared/clamd-scan.conf.template $CLAM_CONF
        			CUSTOM_SCAN_CONF=1
        		else
                   	cp /var/ossec/modules/clamav/template/clamd.conf.template $CLAM_CONF
                   	sed -i "s/^LogFile/#LogFile/g" $CLAM_CONF
                   	sed -i "s/^PidFile/#PidFile/g" $CLAM_CONF
                   	if ! grep -q "^LocalSocket" $CLAM_CONF; then
        				sed -i '/^#LocalSocket/s/^#//g' $CLAM_CONF
                   	fi
        			CUSTOM_SCAN_CONF=0
        		fi
            elif [ -f /etc/clamd.conf ]; then
                CLAM_CONF="/etc/clamd.conf"
                cp /var/ossec/modules/clamav/template/clamd.conf.template /etc/clamd.conf
                cp -f /var/ossec/modules/clamav/template/freshclam.conf.template /etc/freshclam.conf
            fi
            
            FRESHCLAM_CONF="/etc/freshclam.conf"
            if id clamupdate &>/dev/null; then
                sed -i "s/^DatabaseOwner.*/DatabaseOwner clamupdate/g" $FRESHCLAM_CONF
                sed -i "s/^User.*/User clamscan/g" $CLAM_CONF
                chown clamupdate:clamupdate -R /var/lib/clamav >/dev/null 2>&1
            elif id clamav &>/dev/null; then
                sed -i "s/^DatabaseOwner.*/DatabaseOwner clamav/g" $FRESHCLAM_CONF
                sed -i "s/^User.*/User clamav/g" $CLAM_CONF
            fi

            ;;
        "deb")
            CLAM_CONF="/etc/clamav/clamd.conf"
			if [ -f /var/ossec/etc/shared/clamd-scan.conf.template ]; then
				cp /var/ossec/etc/shared/clamd-scan.conf.template $CLAM_CONF
				CUSTOM_SCAN_CONF=1
			else
                # Setup for deb packages
                cp -f /var/ossec/modules/clamav/template/clamd.conf.template /etc/clamav/clamd.conf
				CUSTOM_SCAN_CONF=0
			fi
            cp -f /var/ossec/modules/clamav/template/freshclam.conf.template /etc/clamav/freshclam.conf
            FRESHCLAM_CONF="/etc/clamav/freshclam.conf"

            # Apparmor check
            if systemctl is-active --quiet apparmor; then
                if [ -f /etc/apparmor.d/local/usr.sbin.clamd ]; then
                    if ! grep -q "/** r," /etc/apparmor.d/local/usr.sbin.clamd; then
                        echo "/** r," >> /etc/apparmor.d/local/usr.sbin.clamd
                    fi
                else
                    echo "/** r," > /etc/apparmor.d/local/usr.sbin.clamd
                    systemctl restart apparmor
                fi
            fi
            ;;
        "aix")
            # Setup for AIX packages
            if ! id -g clamav > /dev/null 2>&1; then
                /usr/bin/mkgroup clamav
            fi
            if ! id -u clamav > /dev/null 2>&1; then
                /usr/sbin/useradd -g clamav -G clamav -d /var/lib/clamav clamav
            fi

            if [ ! -f /etc/rc.d/init.d/clamav ]; then
                cp -f /var/ossec/modules/clamav/template/clamav-aix.init /etc/rc.d/init.d/clamav
            fi

            cp -f /var/ossec/modules/clamav/template/clamd.conf.template /opt/freeware/etc/clamav/clamd.conf
            cp -f /var/ossec/modules/clamav/template/freshclam.conf.template /opt/freeware/etc/clamav/freshclam.conf
            CLAM_CONF="/opt/freeware/etc/clamav/clamd.conf"
            FRESHCLAM_CONF="/opt/freeware/etc/clamav/freshclam.conf"

            if [ ! -d /var/log ]; then
                mkdir -p /var/log
            fi
            if [ ! -f /var/log/messages ]; then
                touch /var/log/messages
            fi
            chown clamav /var/lib/clamav

            $SED -i "s/^User.*/User clamav/g" $CLAM_CONF
            $SED -i "s/^DatabaseOwner.*/DatabaseOwner clamav/g" $FRESHCLAM_CONF
            $SED -i "s/^LogFile/#LogFile/g" $CLAM_CONF
            $SED -i "s|^PidFile.*|PidFile /var/run/clamd.pid|" "$CLAM_CONF"
            ;;
        "pkg")
            # Setup for Solaris packages
            cp -f /var/ossec/modules/clamav/template/clamd.conf.template /etc/opt/csw/clamd.conf
            cp -f /var/ossec/modules/clamav/template/freshclam.conf.template /etc/opt/csw/freshclam.conf
            CLAM_CONF="/etc/opt/csw/clamd.conf"
            FRESHCLAM_CONF="/etc/opt/csw/freshclam.conf"
            if [ ! -d /var/log/clamav ]; then
                mkdir -p /var/log/clamav
            fi
            ;;
        *)
            echo "ERROR: Could not complete clamd_setup_and_settings"
            log_event "ERROR: Could not complete clamd_setup_and_settings"
            exit 1
            ;;
    esac

    if [[ $DEBUG -ge 1 ]]; then
        log_event "DEBUG1: clamd_setup_and_settings:: CLAM_CONF is ($CLAM_CONF)"
        log_event "DEBUG1: clamd_setup_and_settings:: SCAN_D is ($SCAN_D)"
        log_event "DEBUG1: clamd_setup_and_settings:: FRESHCLAM_CONF is ($FRESHCLAM_CONF)"
    fi
}


freshclam_settings(){
	if [[ $DEBUG -ge 1 ]]; then
		log_event "DEBUG1: freshclam settings updated: START"
	fi
	if [[ $DIST == "ubuntu" || $DIST == "debian"  ]]; then
		FRESHCLAM_CONF="/etc/clamav/freshclam.conf"
	else
		FRESHCLAM_CONF="/etc/freshclam.conf"
	fi


	# if ENABLE=0 then return, we dont want to update freshclam settings
	if [[ $ENABLE -eq 0 ]]; then
		return 0
	fi

	if [[ ${FRESHCLAM_FEED_TYPE} == "official" ]]; then
		$SED -i '/^DatabaseCustomURL/d' $FRESHCLAM_CONF
		$SED -i '/^ExcludeDatabase/d' $FRESHCLAM_CONF
	else
		if ! grep -q "^DatabaseMirror database.clamav.net" $FRESHCLAM_CONF; then
			echo "DatabaseMirror database.clamav.net" >> $FRESHCLAM_CONF
		fi
		if ! grep -q "^ExcludeDatabase main" $FRESHCLAM_CONF; then
			echo "ExcludeDatabase main" >> $FRESHCLAM_CONF
		fi
		if ! grep -q "^ExcludeDatabase daily" $FRESHCLAM_CONF; then
			echo "ExcludeDatabase daily" >> $FRESHCLAM_CONF
		fi
		if ! grep -q "^ExcludeDatabase daily" $FRESHCLAM_CONF; then
			echo "ExcludeDatabase bytecode" >> $FRESHCLAM_CONF
		fi

		# clear all the DatabaseCustomURL lines that contain atomicorp.com in them
      		$SED -i '/DatabaseCustomURL.*atomicorp\.com/d' $FRESHCLAM_CONF

		if [[ $DEBUG -ge 1 ]]; then
			log_event "DEBUG1: freshclam_settings FRESHCLAM_LINUX_SIGS = ${FRESHCLAM_LINUX_SIGS}"
		fi
		# Populate URLs for the DatabaseCustomURL lines
		EXTENSIONS="fp hdb hdu hsb hsu idb ign2 ldb ldu ndb ndu sfp"
		if [[ ${FRESHCLAM_LINUX_SIGS} == "yes" ]]; then
			for ext in $EXTENSIONS; do
				files_to_add+=(
					"Atomicorp-Linux.${ext}"
				)
			done
		else
			rm -f /var/lib/clamav/Atomicorp-Linux.* >/dev/null 2>&1
		fi
		if [[ ${FRESHCLAM_WINDOWS_SIGS} == "yes" ]]; then
			for ext in $EXTENSIONS; do
				files_to_add+=(
					"Atomicorp-Windows.${ext}"
				)
			done
		else
			rm -f /var/lib/clamav/Atomicorp-Windows.* >/dev/null 2>&1
		fi
		if [[ ${FRESHCLAM_ANDROID_SIGS} == "yes" ]]; then
			for ext in $EXTENSIONS; do
				files_to_add+=(
					"Atomicorp-Android.${ext}"
				)
			done
		else
			rm -f /var/lib/clamav/Atomicorp-Android.* >/dev/null 2>&1
		fi
		if [[ ${FRESHCLAM_OSX_SIGS} == "yes" ]]; then
			for ext in $EXTENSIONS; do
				files_to_add+=(
					"Atomicorp-OSX.${ext}"
				)
			done
		else
			rm -f /var/lib/clamav/Atomicorp-OSX.* >/dev/null 2>&1
		fi

		for file in "${files_to_add[@]}"; do
			echo "DatabaseCustomURL https://rule-updates.atomicorp.com/channels/rules/anti-malware/${file}" >> $FRESHCLAM_CONF
		done


		# Paths to service files
		if [ -f /usr/lib/systemd/system/clamav-daemon.service ]; then
			service_path1="/usr/lib/systemd/system/clamav-daemon.service"
		else
			service_path1="/usr/lib/systemd/system/clamd@.service"
		fi
		service_path2="/lib/systemd/system/clamav-daemon.service"

		if [[ -f "$service_path1" ]]; then
			# Check if the ConditionPath statement exists and comment it out
    		if grep -q "ConditionPathExistsGlob=/var/lib/clamav/" "$service_path1"; then
        		$SED -i 's/ConditionPathExistsGlob=\/var\/lib\/clamav\//#ConditionPathExistsGlob=\/var\/lib\/clamav\//g' "$service_path1"
    			systemctl daemon-reload
    		fi
		elif [[ -f "$service_path2" ]]; then

    		# Check if the ConditionPath statement exists and comment it out
    		if grep -q "ConditionPathExistsGlob=/var/lib/clamav/" "$service_path2"; then
        		$SED -i 's/ConditionPathExistsGlob=\/var\/lib\/clamav\//#ConditionPathExistsGlob=\/var\/lib\/clamav\//g' "$service_path2"
    			systemctl daemon-reload
    		fi
		fi

		if [[ -e /var/lib/clamav/daily.cvd || /var/lib/clamav/main.cvd ]]; then
			FRESHCLAM_RELOAD=1
		fi


	fi

	if [[ $DEBUG -ge 1 ]]; then
		log_event "DEBUG1: freshclam settings updated: END"
	fi

}

clamd_restart() {
    if [[ $DEBUG -ge 1 ]]; then
        log_event "DEBUG1: clamd_restart:: START"
        log_event "DEBUG1: clamd_restart:: ENABLE is $ENABLE"
    fi

    # Exit if running in a Docker container
    if is_docker; then
        if [[ $DEBUG -ge 1 ]]; then
            log_event "DEBUG1: clamd_restart:: Running in Docker, skipping rest of the function"
        fi
        return 0
    fi

    # If ENABLE is 0, disable and stop clamav-daemon and clamonacc
    if [[ $ENABLE -eq 0 ]]; then
        log_event "DEBUG1: clamd_restart:: ENABLE is $ENABLE but we evaluated this as 0"

        case $PKG in
            "rpm" | "deb")
                if [[ $SCAN_D == "true" ]]; then
                    systemctl disable clamd@scan
                    systemctl stop clamd@scan
                else
                    systemctl disable clamav-daemon
                    systemctl stop clamav-daemon
                fi
                if [ -f /usr/lib/systemd/system/clamav-clamonacc.service ]; then
                    systemctl disable clamav-clamonacc >/dev/null 2>&1
                    systemctl stop clamav-clamonacc >/dev/null 2>&1
                else
                    systemctl disable clamonacc >/dev/null 2>&1
                    systemctl stop clamonacc >/dev/null 2>&1
                fi
                killall -9 clamonacc >/dev/null 2>&1
                ;;
            "aix")
                /etc/rc.d/init.d/clamav stop
                ;;
            "pkg")
                svcadm disable svc:/network/cswclamd:default
                ;;
        esac
        return 0
    fi

    # Restart and enable clamav if ENABLE is not 0
    case $PKG in
        "rpm" | "deb")
            if [[ $SCAN_D == "true" ]]; then
                systemctl enable clamd@scan
                systemctl restart clamd@scan
            else
                systemctl enable clamav-daemon
                systemctl restart clamav-daemon
            fi

            if [[ $DEBUG -ge 1 ]]; then
                log_event "DEBUG1: clamd_restart:: systemctl restart clamav-daemon ($?)"
                log_event "DEBUG1: clamd_restart:: INCLUDE_PATHS is ($INCLUDE_PATHS)"
            fi

            if [[ $INCLUDE_PATHS -ge 1 ]]; then
                systemctl enable clamonacc >/dev/null 2>&1
                systemctl start clamonacc >/dev/null 2>&1
                if [[ $DEBUG -ge 1 ]]; then
                    log_event "DEBUG1: clamd_restart:: systemctl start clamonacc ($?)"
                fi
            else
                systemctl disable clamonacc >/dev/null 2>&1
                systemctl stop clamonacc >/dev/null 2>&1
                killall -9 clamonacc >/dev/null 2>&1
                if [[ $DEBUG -ge 1 ]]; then
                    log_event "DEBUG1: clamd_restart:: systemctl stop clamonacc ($?)"
                fi
            fi
            ;;
        "aix")
            /etc/rc.d/init.d/clamav start
            ;;
        "pkg")
            svcadm clear svc:/network/cswclamd:default
            svcadm enable svc:/network/cswclamd:default
            if [[ $DEBUG -ge 1 ]]; then
                log_event "DEBUG1: clamd_restart:: svcadm enable svc:/network/cswclamd:default ($?)"
            fi
            ;;
    esac

    if [[ $DEBUG -ge 1 ]]; then
        log_event "DEBUG1: $0: clamd_restart:: END"
    fi
}






freshclam_update() {
	if [[ $DEBUG -ge 1 ]]; then
		log_event "DEBUG1: freshclam update: START"
	fi

    if [[ "$PKG" == "rpm" ]]; then
       	if ! is_docker ; then
			systemctl stop freshclam
		fi
    elif [[ "$PKG" == "deb" ]]; then
       	if ! is_docker ; then
			systemctl stop clamav-freshclam
		fi
  	fi

	if [[ ${FRESHCLAM_RELOAD} == 1 ]]; then
		/var/ossec/modules/clamav/freshclam 
		RET=$?
	fi

	if [[ $DEBUG -ge 1 ]]; then
		log_event "DEBUG1: freshclam update: ($RET) END"
	fi
}

# create a function to quarantine files
quarantine_settings() {
	if [[ $DEBUG -ge 1 ]]; then
		log_event "DEBUG1: quarantine_settings:: START"
		log_event "DEBUG1: quarantine_settings:: QUARANTINE (${QUARANTINE})"
	fi

	if [[ ${QUARANTINE} == 1 ]]; then
		if [[ ${QUARANTINE_PATH} == "" ]]; then
			QUARANTINE_PATH="/var/awp/data/suspicious"
		fi

		# write to the file /etc/default/clamav-daemon
		if [[ ! -d /etc/default/ ]]; then
			mkdir /etc/default/
		fi
		echo "OPTIONS=\"--move=${QUARANTINE_PATH}\"" > /etc/default/clamav-daemon

	else
		if [[ -f /etc/default/clamav-daemon ]]; then
			$SED -i 's/OPTIONS=.*/OPTIONS=""/g' /etc/default/clamav-daemon
		fi
	fi

	if ! is_docker && [[ "$PKG" == "rpm" || "$PKG" == "deb" ]]; then
	    if [[ $REALTIME -eq 1 ]]; then

	    	if [ -f /usr/lib/systemd/system/clamav-clamonacc.service ]; then
	    		if [ -f /etc/systemd/system/clamonacc.service ]; then
	    			rm -f /etc/systemd/system/clamonacc.service
	    		fi
	    		systemctl enable clamav-clamonacc.service
	    		if [[ $DEBUG -ge 1 ]]; then
	    			log_event "DEBUG1: quarantine_settings:: enable clamonacc.service:($?) "
	    		fi
	    	else 
	    		cp /var/ossec/modules/clamav/template/clamonacc.service /etc/systemd/system/clamonacc.service
	    		systemctl daemon-reload
	    		systemctl enable clamonacc.service
	    		if [[ $DEBUG -ge 1 ]]; then
	    			log_event "DEBUG1: quarantine_settings:: enable clamonacc.service:($?) "
	    		fi
	    	fi
	    	if [[ $DEBUG -ge 1 ]]; then
	    		log_event "DEBUG1: quarantine_settings:: enable clamonacc.service:($?) "
	    	fi
	    else
	    	if [ -f /usr/lib/systemd/system/clamav-clamonacc.service ]; then
	    		systemctl disable clamav-clamonacc
	    		systemctl stop clamav-clamonacc
	    	else
	    		systemctl disable clamonacc.service
	    		systemctl stop clamonacc.service
	    		rm -f /etc/systemd/system/clamonacc.service
	    		systemctl daemon-reload
	    	fi
	    fi
	fi

	if [[ $DEBUG -ge 1 ]]; then
		log_event "DEBUG1: quarantine_settings:: END"
	fi
}

function log_event () {
    MSG=$1
    MODULE_NAME=${MODULE_NAME:-"atomicorp-api-module"}
    echo "`date "+%b %d %H:%M:%S"` ${HOSTNAME} ${MODULE_NAME}: ${MSG}" >> ${LOG_FILE}
    logger -t ${MODULE_NAME} "${MSG} Agent ID: ${ID} "
}


# Function to check if running in Docker environment
function is_docker() {
	if [ -f "/.dockerenv" ]; then
		return 0  # Running in Docker
	else
		return 1  # Not running in Docker
	fi
}
